""""""

TYPE_CPP2PY = {
    "int": "int",
    "long long": "int",
    "char": "char",
    "double": "double",
    "short": "int",
}


class DataTypeGenerator:
    """DataType生成器"""

    def __init__(self, filename: str, prefix: str) -> None:
        """Constructor"""
        self.filename = filename
        self.prefix = prefix

    def run(self) -> None:
        """主函数"""
        self.f_cpp = open(self.filename)
        self.f_define = open(f"{self.prefix}_constant.py", "w")
        self.f_typedef = open(f"{self.prefix}_typedef.py", "w")

        for line in self.f_cpp:
            self.process_line(line)

        self.f_cpp.close()
        self.f_define.close()
        self.f_typedef.close()

        print("DataType生成完毕")

    def process_line(self, line: str) -> None:
        """处理每行"""
        line = line.replace("\n", "")
        line = line.replace(";", "")

        if line.startswith("#define"):
            self.process_define(line)
        elif line.startswith("typedef"):
            self.process_typedef(line)

    def process_define(self, line: str) -> None:
        """处理常量定义"""
        words = line.split(" ")
        words = [word for word in words if word]
        if len(words) < 3:
            return

        name = words[1]
        value = words[2]

        new_line = f"{name} = {value}\n"
        self.f_define.write(new_line)

    def process_typedef(self, line: str) -> None:
        """处理类型定义"""
        words = line.split(" ")
        words = [word for word in words if word != " "]

        if "long long" in line:
            name = words[3]
            typedef = "int"
        else:
            name = words[2]
            typedef = TYPE_CPP2PY[words[1]]

        if typedef == "char":
            if "[" in name:
                typedef = "string"
                name = name[:name.index("[")]

        new_line = f"{name} = \"{typedef}\"\n"

        if "long long" in line:
            print(line)
            print(new_line)
        self.f_typedef.write(new_line)


if __name__ == "__main__":
    generator = DataTypeGenerator("../include/sopt/ThostFtdcUserApiDataType.h", "sopt")
    generator.run()



""""""
import importlib


class ApiGenerator:
    """API生成器"""""

    def __init__(self, filename: str, prefix: str, name: str, class_name: str) -> None:
        """Constructor"""
        self.filename = filename
        self.prefix = prefix
        self.name = name
        self.class_name = class_name

        self.callbacks: dict[str, dict[str, str]] = {}
        self.functions: dict[str, dict[str, str]] = {}
        self.lines: dict[str, str] = {}

        self.structs: dict[str, dict[str, str]] = {}
        self.load_struct()

    def load_struct(self) -> None:
        """加载Struct"""
        module_name = f"{self.prefix}_struct"
        module = importlib.import_module(module_name)

        for name in dir(module):
            if "__" not in name:
                self.structs[name] = getattr(module, name)

    def run(self) -> None:
        """运行生成"""
        self.f_cpp = open(self.filename)

        for line in self.f_cpp:
            self.process_line(line)

        self.f_cpp.close()

        self.generate_header_define()
        self.generate_header_process()
        self.generate_header_on()
        self.generate_header_function()

        self.generate_source_task()
        self.generate_source_switch()
        self.generate_source_process()
        self.generate_source_function()
        self.generate_source_on()
        self.generate_source_module()

        print("API生成成功")

    def process_line(self, line: str) -> None:
        """处理每行"""
        line = line.replace(";", "")
        line = line.replace("\n", "")
        line = line.replace("\t", "")
        line = line.replace("{}", "")

        if "virtual void On" in line:
            self.process_callback(line)
        elif "virtual int Req" in line:
            self.process_function(line)

    def process_callback(self, line: str) -> None:
        """处理回掉函数"""
        name = line[line.index("On"):line.index("(")]
        self.lines[name] = line

        d = self.generate_arg_dict(line)
        self.callbacks[name] = d

    def process_function(self, line: str) -> None:
        """处理主动函数"""
        name = line[line.index("Req"):line.index("(")]

        d = self.generate_arg_dict(line)
        self.functions[name] = d

    def generate_arg_dict(self, line: str) -> dict[str, str]:
        """生成参数字典"""
        args_str = line[line.index("(") + 1:line.index(")")]
        if not args_str:
            return {}
        args = args_str.split(",")

        d = {}
        for arg in args:
            words = arg.split(" ")
            words = [word for word in words if word]
            d[words[1].replace("*", "")] = words[0]
        return d

    def generate_header_define(self) -> None:
        """"""
        filename = f"{self.prefix}_{self.name}_header_define.h"
        with open(filename, "w") as f:
            for n, name in enumerate(self.callbacks.keys()):
                line = f"#define {name.upper()} {n}\n"
                f.write(line)

    def generate_header_process(self) -> None:
        """"""
        filename = f"{self.prefix}_{self.name}_header_process.h"
        with open(filename, "w") as f:
            for name in self.callbacks.keys():
                name = name.replace("On", "process")
                line = f"void {name}(Task *task);\n\n"
                f.write(line)

    def generate_header_on(self) -> None:
        """"""
        filename = f"{self.prefix}_{self.name}_header_on.h"
        with open(filename, "w") as f:
            for name, d in self.callbacks.items():
                name = name.replace("On", "on")

                args_list = []
                for type_ in d.values():
                    if type_ == "int":
                        args_list.append("int reqid")
                    elif type_ == "bool":
                        args_list.append("bool last")
                    elif type_ == "char*":
                        args_list.append("string data")
                    elif type_ == "CThostFtdcRspInfoField":
                        args_list.append("const dict &error")
                    else:
                        args_list.append("const dict &data")

                args_str = ", ".join(args_list)
                line = f"virtual void {name}({args_str}) {{}};\n\n"

                f.write(line)

    def generate_header_function(self) -> None:
        """"""
        filename = f"{self.prefix}_{self.name}_header_function.h"
        with open(filename, "w") as f:
            for name in self.functions.keys():
                name = name.replace("Req", "req")
                line = f"int {name}(const dict &req, int reqid);\n\n"
                f.write(line)

    def generate_source_task(self) -> None:
        """"""
        filename = f"{self.prefix}_{self.name}_source_task.cpp"
        with open(filename, "w") as f:
            for name, d in self.callbacks.items():
                line = self.lines[name]

                f.write(line.replace("virtual void ",
                                     f"void {self.class_name}::") + "\n")
                f.write("{\n")
                f.write("\tTask task = Task();\n")
                f.write(f"\ttask.task_name = {name.upper()};\n")

                for field, type_ in d.items():
                    if type_ == "int":
                        f.write(f"\ttask.task_id = {field};\n")
                    elif type_ == "bool":
                        f.write(f"\ttask.task_last = {field};\n")
                    elif type_ == "CThostFtdcRspInfoField":
                        f.write(f"\tif ({field})\n")
                        f.write("\t{\n")
                        f.write(f"\t\t{type_} *task_error = new {type_}();\n")
                        f.write(f"\t\t*task_error = *{field};\n")
                        f.write("\t\ttask.task_error = task_error;\n")
                        f.write("\t}\n")
                    else:
                        f.write(f"\tif ({field})\n")
                        f.write("\t{\n")
                        f.write(f"\t\t{type_} *task_data = new {type_}();\n")
                        f.write(f"\t\t*task_data = *{field};\n")
                        f.write("\t\ttask.task_data = task_data;\n")
                        f.write("\t}\n")

                f.write("\tthis->task_queue.push(task);\n")
                f.write("};\n\n")

    def generate_source_switch(self) -> None:
        """"""
        filename = f"{self.prefix}_{self.name}_source_switch.cpp"
        with open(filename, "w") as f:
            for name in self.callbacks.keys():
                process_name = name.replace("On", "process")
                f.write(f"case {name.upper()}:\n")
                f.write("{\n")
                f.write(f"\tthis->{process_name}(&task);\n")
                f.write("\tbreak;\n")
                f.write("}\n\n")

    def generate_source_process(self) -> None:
        """"""
        filename = f"{self.prefix}_{self.name}_source_process.cpp"
        with open(filename, "w") as f:
            for name, d in self.callbacks.items():
                process_name = name.replace("On", "process")
                on_name = name.replace("On", "on")

                f.write(
                    f"void {self.class_name}::{process_name}(Task *task)\n")
                f.write("{\n")
                f.write("\tgil_scoped_acquire acquire;\n")

                args = []

                for _field, type_ in d.items():
                    if type_ == "int":
                        args.append("task->task_id")
                    elif type_ == "bool":
                        args.append("task->task_last")
                    elif type_ == "CThostFtdcRspInfoField":
                        args.append("error")

                        f.write("\tdict error;\n")
                        f.write("\tif (task->task_error)\n")
                        f.write("\t{\n")
                        f.write(
                            f"\t\t{type_} *task_error = ({type_}*)task->task_error;\n")

                        struct_fields = self.structs[type_]
                        for struct_field, struct_type in struct_fields.items():
                            if struct_type == "string":
                                f.write(
                                    f"\t\terror[\"{struct_field}\"] = toUtf(task_error->{struct_field});\n")
                            else:
                                f.write(
                                    f"\t\terror[\"{struct_field}\"] = task_error->{struct_field};\n")

                        f.write("\t\tdelete task_error;\n")
                        f.write("\t}\n")
                    else:
                        args.append("data")

                        f.write("\tdict data;\n")
                        f.write("\tif (task->task_data)\n")
                        f.write("\t{\n")
                        f.write(
                            f"\t\t{type_} *task_data = ({type_}*)task->task_data;\n")

                        struct_fields = self.structs[type_]
                        for struct_field, struct_type in struct_fields.items():
                            if struct_type == "string":
                                f.write(
                                    f"\t\tdata[\"{struct_field}\"] = toUtf(task_data->{struct_field});\n")
                            else:
                                f.write(
                                    f"\t\tdata[\"{struct_field}\"] = task_data->{struct_field};\n")

                        f.write("\t\tdelete task_data;\n")
                        f.write("\t}\n")

                args_str = ", ".join(args)
                f.write(f"\tthis->{on_name}({args_str});\n")
                f.write("};\n\n")

    def generate_source_function(self) -> None:
        """"""
        filename = f"{self.prefix}_{self.name}_source_function.cpp"
        with open(filename, "w") as f:
            for name, d in self.functions.items():
                req_name = name.replace("Req", "req")
                type_ = list(d.values())[0]

                f.write(
                    f"int {self.class_name}::{req_name}(const dict &req, int reqid)\n")
                f.write("{\n")
                f.write(f"\t{type_} myreq = {type_}();\n")
                f.write("\tmemset(&myreq, 0, sizeof(myreq));\n")

                struct_fields = self.structs[type_]
                for struct_field, struct_type in struct_fields.items():
                    if struct_type == "string":
                        line = f"\tgetString(req, \"{struct_field}\", myreq.{struct_field});\n"
                    else:
                        line = f"\tget{struct_type.capitalize()}(req, \"{struct_field}\", &myreq.{struct_field});\n"
                    f.write(line)

                f.write(f"\tint i = this->api->{name}(&myreq, reqid);\n")
                f.write("\treturn i;\n")
                f.write("};\n\n")

    def generate_source_on(self) -> None:
        """"""
        filename = f"{self.prefix}_{self.name}_source_on.cpp"
        with open(filename, "w") as f:
            for name, d in self.callbacks.items():
                on_name = name.replace("On", "on")

                args = []
                bind_args = ["void", self.class_name, on_name]
                for _field, type_ in d.items():
                    if type_ == "int":
                        args.append("int reqid")
                        bind_args.append("reqid")
                    elif type_ == "bool":
                        args.append("bool last")
                        bind_args.append("last")
                    elif type_ == "CThostFtdcRspInfoField":
                        args.append("const dict &error")
                        bind_args.append("error")
                    else:
                        args.append("const dict &data")
                        bind_args.append("data")

                args_str = ", ".join(args)
                bind_args_str = ", ".join(bind_args)

                f.write(f"void {on_name}({args_str}) override\n")
                f.write("{\n")
                f.write("\ttry\n")
                f.write("\t{\n")
                f.write(f"\t\tPYBIND11_OVERLOAD({bind_args_str});\n")
                f.write("\t}\n")
                f.write("\tcatch (const error_already_set &e)\n")
                f.write("\t{\n")
                f.write("\t\tcout << e.what() << endl;\n")
                f.write("\t}\n")
                f.write("};\n\n")

    def generate_source_module(self) -> None:
        """"""
        filename = f"{self.prefix}_{self.name}_source_module.cpp"
        with open(filename, "w") as f:
            for name in self.functions.keys():
                name = name.replace("Req", "req")
                f.write(f".def(\"{name}\", &{self.class_name}::{name})\n")

            f.write("\n")

            for name in self.callbacks.keys():
                name = name.replace("On", "on")
                f.write(f".def(\"{name}\", &{self.class_name}::{name})\n")

            f.write(";\n")


if __name__ == "__main__":
    md_generator = ApiGenerator("../include/sopt/ThostFtdcMdApi.h", "sopt", "md", "MdApi")
    md_generator.run()

    td_generator = ApiGenerator("../include/sopt/ThostFtdcTraderApi.h", "sopt", "td", "TdApi")
    td_generator.run()



TThostFtdcTraderIDType = "string"
TThostFtdcInvestorIDType = "string"
TThostFtdcBrokerIDType = "string"
TThostFtdcBrokerAbbrType = "string"
TThostFtdcBrokerNameType = "string"
TThostFtdcExchangeInstIDType = "string"
TThostFtdcOrderRefType = "string"
TThostFtdcParticipantIDType = "string"
TThostFtdcUserIDType = "string"
TThostFtdcPasswordType = "string"
TThostFtdcClientIDType = "string"
TThostFtdcInstrumentIDType = "string"
TThostFtdcInstrumentCodeType = "string"
TThostFtdcMarketIDType = "string"
TThostFtdcProductNameType = "string"
TThostFtdcExchangeIDType = "string"
TThostFtdcExchangeNameType = "string"
TThostFtdcExchangeAbbrType = "string"
TThostFtdcExchangeFlagType = "string"
TThostFtdcMacAddressType = "string"
TThostFtdcSystemIDType = "string"
TThostFtdcExchangePropertyType = "char"
TThostFtdcDateType = "string"
TThostFtdcTimeType = "string"
TThostFtdcLongTimeType = "string"
TThostFtdcOldInstrumentNameType = "string"
TThostFtdcSettlementGroupIDType = "string"
TThostFtdcOrderSysIDType = "string"
TThostFtdcTradeIDType = "string"
TThostFtdcCommandTypeType = "string"
TThostFtdcOldIPAddressType = "string"
TThostFtdcIPAddressType = "string"
TThostFtdcClientLoginRemarkType = "string"
TThostFtdcIPPortType = "int"
TThostFtdcProductInfoType = "string"
TThostFtdcProtocolInfoType = "string"
TThostFtdcBusinessUnitType = "string"
TThostFtdcDepositSeqNoType = "string"
TThostFtdcIdentifiedCardNoType = "string"
TThostFtdcIdCardTypeType = "char"
TThostFtdcOrderLocalIDType = "string"
TThostFtdcUserNameType = "string"
TThostFtdcPartyNameType = "string"
TThostFtdcErrorMsgType = "string"
TThostFtdcFieldNameType = "string"
TThostFtdcFieldContentType = "string"
TThostFtdcSystemNameType = "string"
TThostFtdcContentType = "string"
TThostFtdcInvestorRangeType = "char"
TThostFtdcDepartmentRangeType = "char"
TThostFtdcDataSyncStatusType = "char"
TThostFtdcBrokerDataSyncStatusType = "char"
TThostFtdcExchangeConnectStatusType = "char"
TThostFtdcTraderConnectStatusType = "char"
TThostFtdcFunctionCodeType = "char"
TThostFtdcBrokerFunctionCodeType = "char"
TThostFtdcOrderActionStatusType = "char"
TThostFtdcOrderStatusType = "char"
TThostFtdcOrderSubmitStatusType = "char"
TThostFtdcPositionDateType = "char"
TThostFtdcPositionDateTypeType = "char"
TThostFtdcTradingRoleType = "char"
TThostFtdcProductClassType = "char"
TThostFtdcInstLifePhaseType = "char"
TThostFtdcDirectionType = "char"
TThostFtdcPositionTypeType = "char"
TThostFtdcPosiDirectionType = "char"
TThostFtdcSysSettlementStatusType = "char"
TThostFtdcRatioAttrType = "char"
TThostFtdcHedgeFlagType = "char"
TThostFtdcBillHedgeFlagType = "char"
TThostFtdcClientIDTypeType = "char"
TThostFtdcOrderPriceTypeType = "char"
TThostFtdcOffsetFlagType = "char"
TThostFtdcForceCloseReasonType = "char"
TThostFtdcOrderTypeType = "char"
TThostFtdcInvestorProgrammingTypeType = "char"
TThostFtdcClientNameType = "string"
TThostFtdcTimeConditionType = "char"
TThostFtdcVolumeConditionType = "char"
TThostFtdcContingentConditionType = "char"
TThostFtdcActionFlagType = "char"
TThostFtdcTradingRightType = "char"
TThostFtdcOrderSourceType = "char"
TThostFtdcTradeTypeType = "char"
TThostFtdcPriceSourceType = "char"
TThostFtdcInstrumentStatusType = "char"
TThostFtdcInstStatusEnterReasonType = "char"
TThostFtdcOrderActionRefType = "int"
TThostFtdcInstallCountType = "int"
TThostFtdcInstallIDType = "int"
TThostFtdcErrorIDType = "int"
TThostFtdcSettlementIDType = "int"
TThostFtdcVolumeType = "int"
TThostFtdcFrontIDType = "int"
TThostFtdcSessionIDType = "int"
TThostFtdcSequenceNoType = "int"
TThostFtdcCommandNoType = "int"
TThostFtdcMillisecType = "int"
TThostFtdcVolumeMultipleType = "int"
TThostFtdcTradingSegmentSNType = "int"
TThostFtdcRequestIDType = "int"
TThostFtdcYearType = "int"
TThostFtdcMonthType = "int"
TThostFtdcBoolType = "int"
TThostFtdcPriceType = "double"
TThostFtdcCombOffsetFlagType = "string"
TThostFtdcCombHedgeFlagType = "string"
TThostFtdcRatioType = "double"
TThostFtdcMoneyType = "double"
TThostFtdcLargeVolumeType = "double"
TThostFtdcSequenceSeriesType = "int"
TThostFtdcCommPhaseNoType = "int"
TThostFtdcSequenceLabelType = "string"
TThostFtdcUnderlyingMultipleType = "double"
TThostFtdcPriorityType = "int"
TThostFtdcContractCodeType = "string"
TThostFtdcCityType = "string"
TThostFtdcIsStockType = "string"
TThostFtdcChannelType = "string"
TThostFtdcAddressType = "string"
TThostFtdcZipCodeType = "string"
TThostFtdcTelephoneType = "string"
TThostFtdcFaxType = "string"
TThostFtdcMobileType = "string"
TThostFtdcEMailType = "string"
TThostFtdcMemoType = "string"
TThostFtdcCompanyCodeType = "string"
TThostFtdcWebsiteType = "string"
TThostFtdcTaxNoType = "string"
TThostFtdcBatchStatusType = "char"
TThostFtdcPropertyIDType = "string"
TThostFtdcPropertyNameType = "string"
TThostFtdcLicenseNoType = "string"
TThostFtdcAgentIDType = "string"
TThostFtdcAgentNameType = "string"
TThostFtdcAgentGroupIDType = "string"
TThostFtdcAgentGroupNameType = "string"
TThostFtdcReturnStyleType = "char"
TThostFtdcReturnPatternType = "char"
TThostFtdcReturnLevelType = "char"
TThostFtdcReturnStandardType = "char"
TThostFtdcMortgageTypeType = "char"
TThostFtdcInvestorSettlementParamIDType = "char"
TThostFtdcExchangeSettlementParamIDType = "char"
TThostFtdcSystemParamIDType = "char"
TThostFtdcTradeParamIDType = "char"
TThostFtdcSettlementParamValueType = "string"
TThostFtdcCounterIDType = "string"
TThostFtdcInvestorGroupNameType = "string"
TThostFtdcBrandCodeType = "string"
TThostFtdcWarehouseType = "string"
TThostFtdcProductDateType = "string"
TThostFtdcGradeType = "string"
TThostFtdcClassifyType = "string"
TThostFtdcPositionType = "string"
TThostFtdcYieldlyType = "string"
TThostFtdcWeightType = "string"
TThostFtdcSubEntryFundNoType = "int"
TThostFtdcFileIDType = "char"
TThostFtdcFileNameType = "string"
TThostFtdcFileTypeType = "char"
TThostFtdcFileFormatType = "char"
TThostFtdcFileUploadStatusType = "char"
TThostFtdcTransferDirectionType = "char"
TThostFtdcUploadModeType = "string"
TThostFtdcAccountIDType = "string"
TThostFtdcBankFlagType = "string"
TThostFtdcBankAccountType = "string"
TThostFtdcOpenNameType = "string"
TThostFtdcOpenBankType = "string"
TThostFtdcBankNameType = "string"
TThostFtdcPublishPathType = "string"
TThostFtdcOperatorIDType = "string"
TThostFtdcMonthCountType = "int"
TThostFtdcAdvanceMonthArrayType = "string"
TThostFtdcDateExprType = "string"
TThostFtdcInstrumentIDExprType = "string"
TThostFtdcInstrumentNameExprType = "string"
TThostFtdcSpecialCreateRuleType = "char"
TThostFtdcBasisPriceTypeType = "char"
TThostFtdcProductLifePhaseType = "char"
TThostFtdcDeliveryModeType = "char"
TThostFtdcLogLevelType = "string"
TThostFtdcProcessNameType = "string"
TThostFtdcOperationMemoType = "string"
TThostFtdcFundIOTypeType = "char"
TThostFtdcFundTypeType = "char"
TThostFtdcFundDirectionType = "char"
TThostFtdcFundStatusType = "char"
TThostFtdcBillNoType = "string"
TThostFtdcBillNameType = "string"
TThostFtdcPublishStatusType = "char"
TThostFtdcEnumValueIDType = "string"
TThostFtdcEnumValueTypeType = "string"
TThostFtdcEnumValueLabelType = "string"
TThostFtdcEnumValueResultType = "string"
TThostFtdcSystemStatusType = "char"
TThostFtdcSettlementStatusType = "char"
TThostFtdcRangeIntTypeType = "string"
TThostFtdcRangeIntFromType = "string"
TThostFtdcRangeIntToType = "string"
TThostFtdcFunctionIDType = "string"
TThostFtdcFunctionValueCodeType = "string"
TThostFtdcFunctionNameType = "string"
TThostFtdcRoleIDType = "string"
TThostFtdcRoleNameType = "string"
TThostFtdcDescriptionType = "string"
TThostFtdcCombineIDType = "string"
TThostFtdcCombineTypeType = "string"
TThostFtdcInvestorTypeType = "char"
TThostFtdcBrokerTypeType = "char"
TThostFtdcRiskLevelType = "char"
TThostFtdcFeeAcceptStyleType = "char"
TThostFtdcPasswordTypeType = "char"
TThostFtdcAlgorithmType = "char"
TThostFtdcIncludeCloseProfitType = "char"
TThostFtdcAllWithoutTradeType = "char"
TThostFtdcCommentType = "string"
TThostFtdcVersionType = "string"
TThostFtdcTradeCodeType = "string"
TThostFtdcTradeDateType = "string"
TThostFtdcTradeTimeType = "string"
TThostFtdcTradeSerialType = "string"
TThostFtdcTradeSerialNoType = "int"
TThostFtdcFutureIDType = "string"
TThostFtdcBankIDType = "string"
TThostFtdcBankBrchIDType = "string"
TThostFtdcBankBranchIDType = "string"
TThostFtdcOperNoType = "string"
TThostFtdcDeviceIDType = "string"
TThostFtdcRecordNumType = "string"
TThostFtdcFutureAccountType = "string"
TThostFtdcFuturePwdFlagType = "char"
TThostFtdcTransferTypeType = "char"
TThostFtdcFutureAccPwdType = "string"
TThostFtdcCurrencyCodeType = "string"
TThostFtdcRetCodeType = "string"
TThostFtdcRetInfoType = "string"
TThostFtdcTradeAmtType = "string"
TThostFtdcUseAmtType = "string"
TThostFtdcFetchAmtType = "string"
TThostFtdcTransferValidFlagType = "char"
TThostFtdcCertCodeType = "string"
TThostFtdcBankChannelType = "char"
TThostFtdcReasonType = "char"
TThostFtdcFundProjectIDType = "string"
TThostFtdcSexType = "char"
TThostFtdcProfessionType = "string"
TThostFtdcNationalType = "string"
TThostFtdcProvinceType = "string"
TThostFtdcRegionType = "string"
TThostFtdcCountryType = "string"
TThostFtdcLicenseNOType = "string"
TThostFtdcCompanyTypeType = "string"
TThostFtdcBusinessScopeType = "string"
TThostFtdcCapitalCurrencyType = "string"
TThostFtdcUserTypeType = "char"
TThostFtdcBranchIDType = "string"
TThostFtdcRateTypeType = "char"
TThostFtdcNoteTypeType = "char"
TThostFtdcSettlementStyleType = "char"
TThostFtdcBrokerDNSType = "string"
TThostFtdcSentenceType = "string"
TThostFtdcSettlementBillTypeType = "char"
TThostFtdcUserRightTypeType = "char"
TThostFtdcMarginPriceTypeType = "char"
TThostFtdcBillGenStatusType = "char"
TThostFtdcAlgoTypeType = "char"
TThostFtdcHandlePositionAlgoIDType = "char"
TThostFtdcFindMarginRateAlgoIDType = "char"
TThostFtdcHandleTradingAccountAlgoIDType = "char"
TThostFtdcPersonTypeType = "char"
TThostFtdcQueryInvestorRangeType = "char"
TThostFtdcInvestorRiskStatusType = "char"
TThostFtdcLegIDType = "int"
TThostFtdcLegMultipleType = "int"
TThostFtdcImplyLevelType = "int"
TThostFtdcClearAccountType = "string"
TThostFtdcOrganNOType = "string"
TThostFtdcClearbarchIDType = "string"
TThostFtdcUserEventTypeType = "char"
TThostFtdcUserEventInfoType = "string"
TThostFtdcCloseStyleType = "char"
TThostFtdcStatModeType = "char"
TThostFtdcParkedOrderStatusType = "char"
TThostFtdcParkedOrderIDType = "string"
TThostFtdcParkedOrderActionIDType = "string"
TThostFtdcVirDealStatusType = "char"
TThostFtdcOrgSystemIDType = "char"
TThostFtdcVirTradeStatusType = "char"
TThostFtdcVirBankAccTypeType = "char"
TThostFtdcVirementStatusType = "char"
TThostFtdcVirementAvailAbilityType = "char"
TThostFtdcVirementTradeCodeType = "char"
TThostFtdcPhotoTypeNameType = "string"
TThostFtdcPhotoTypeIDType = "string"
TThostFtdcPhotoNameType = "string"
TThostFtdcTopicIDType = "int"
TThostFtdcReportTypeIDType = "string"
TThostFtdcCharacterIDType = "string"
TThostFtdcAMLParamIDType = "string"
TThostFtdcAMLInvestorTypeType = "string"
TThostFtdcAMLIdCardTypeType = "string"
TThostFtdcAMLTradeDirectType = "string"
TThostFtdcAMLTradeModelType = "string"
TThostFtdcAMLOpParamValueType = "double"
TThostFtdcAMLCustomerCardTypeType = "string"
TThostFtdcAMLInstitutionNameType = "string"
TThostFtdcAMLDistrictIDType = "string"
TThostFtdcAMLRelationShipType = "string"
TThostFtdcAMLInstitutionTypeType = "string"
TThostFtdcAMLInstitutionIDType = "string"
TThostFtdcAMLAccountTypeType = "string"
TThostFtdcAMLTradingTypeType = "string"
TThostFtdcAMLTransactClassType = "string"
TThostFtdcAMLCapitalIOType = "string"
TThostFtdcAMLSiteType = "string"
TThostFtdcAMLCapitalPurposeType = "string"
TThostFtdcAMLReportTypeType = "string"
TThostFtdcAMLSerialNoType = "string"
TThostFtdcAMLStatusType = "string"
TThostFtdcAMLGenStatusType = "char"
TThostFtdcAMLSeqCodeType = "string"
TThostFtdcAMLFileNameType = "string"
TThostFtdcAMLMoneyType = "double"
TThostFtdcAMLFileAmountType = "int"
TThostFtdcCFMMCKeyType = "string"
TThostFtdcCFMMCTokenType = "string"
TThostFtdcCFMMCKeyKindType = "char"
TThostFtdcAMLReportNameType = "string"
TThostFtdcDBFComdTypeType = "string"
TThostFtdcDBFComTimeType = "string"
TThostFtdcDBFComNoType = "string"
TThostFtdcDBFFdNameType = "string"
TThostFtdcDBFFdContentType = "string"
TThostFtdcIndividualNameType = "string"
TThostFtdcCurrencyIDType = "string"
TThostFtdcCustNumberType = "string"
TThostFtdcOrganCodeType = "string"
TThostFtdcOrganNameType = "string"
TThostFtdcSuperOrganCodeType = "string"
TThostFtdcSubBranchIDType = "string"
TThostFtdcSubBranchNameType = "string"
TThostFtdcBranchNetCodeType = "string"
TThostFtdcBranchNetNameType = "string"
TThostFtdcOrganFlagType = "string"
TThostFtdcBankCodingForFutureType = "string"
TThostFtdcBankReturnCodeType = "string"
TThostFtdcPlateReturnCodeType = "string"
TThostFtdcBankSubBranchIDType = "string"
TThostFtdcFutureBranchIDType = "string"
TThostFtdcReturnCodeType = "string"
TThostFtdcOperatorCodeType = "string"
TThostFtdcClearDepIDType = "string"
TThostFtdcClearBrchIDType = "string"
TThostFtdcClearNameType = "string"
TThostFtdcBankAccountNameType = "string"
TThostFtdcInvDepIDType = "string"
TThostFtdcInvBrchIDType = "string"
TThostFtdcMessageFormatVersionType = "string"
TThostFtdcDigestType = "string"
TThostFtdcAuthenticDataType = "string"
TThostFtdcPasswordKeyType = "string"
TThostFtdcFutureAccountNameType = "string"
TThostFtdcMobilePhoneType = "string"
TThostFtdcFutureMainKeyType = "string"
TThostFtdcFutureWorkKeyType = "string"
TThostFtdcFutureTransKeyType = "string"
TThostFtdcBankMainKeyType = "string"
TThostFtdcBankWorkKeyType = "string"
TThostFtdcBankTransKeyType = "string"
TThostFtdcBankServerDescriptionType = "string"
TThostFtdcAddInfoType = "string"
TThostFtdcDescrInfoForReturnCodeType = "string"
TThostFtdcCountryCodeType = "string"
TThostFtdcSerialType = "int"
TThostFtdcPlateSerialType = "int"
TThostFtdcBankSerialType = "string"
TThostFtdcCorrectSerialType = "int"
TThostFtdcFutureSerialType = "int"
TThostFtdcApplicationIDType = "int"
TThostFtdcBankProxyIDType = "int"
TThostFtdcFBTCoreIDType = "int"
TThostFtdcServerPortType = "int"
TThostFtdcRepealedTimesType = "int"
TThostFtdcRepealTimeIntervalType = "int"
TThostFtdcTotalTimesType = "int"
TThostFtdcFBTRequestIDType = "int"
TThostFtdcTIDType = "int"
TThostFtdcTradeAmountType = "double"
TThostFtdcCustFeeType = "double"
TThostFtdcFutureFeeType = "double"
TThostFtdcSingleMaxAmtType = "double"
TThostFtdcSingleMinAmtType = "double"
TThostFtdcTotalAmtType = "double"
TThostFtdcCertificationTypeType = "char"
TThostFtdcFileBusinessCodeType = "char"
TThostFtdcCashExchangeCodeType = "char"
TThostFtdcYesNoIndicatorType = "char"
TThostFtdcBanlanceTypeType = "char"
TThostFtdcGenderType = "char"
TThostFtdcFeePayFlagType = "char"
TThostFtdcPassWordKeyTypeType = "char"
TThostFtdcFBTPassWordTypeType = "char"
TThostFtdcFBTEncryModeType = "char"
TThostFtdcBankRepealFlagType = "char"
TThostFtdcBrokerRepealFlagType = "char"
TThostFtdcInstitutionTypeType = "char"
TThostFtdcLastFragmentType = "char"
TThostFtdcBankAccStatusType = "char"
TThostFtdcMoneyAccountStatusType = "char"
TThostFtdcManageStatusType = "char"
TThostFtdcSystemTypeType = "char"
TThostFtdcTxnEndFlagType = "char"
TThostFtdcProcessStatusType = "char"
TThostFtdcCustTypeType = "char"
TThostFtdcFBTTransferDirectionType = "char"
TThostFtdcOpenOrDestroyType = "char"
TThostFtdcAvailabilityFlagType = "char"
TThostFtdcOrganTypeType = "char"
TThostFtdcOrganLevelType = "char"
TThostFtdcProtocalIDType = "char"
TThostFtdcConnectModeType = "char"
TThostFtdcSyncModeType = "char"
TThostFtdcBankAccTypeType = "char"
TThostFtdcFutureAccTypeType = "char"
TThostFtdcOrganStatusType = "char"
TThostFtdcCCBFeeModeType = "char"
TThostFtdcCommApiTypeType = "char"
TThostFtdcServiceIDType = "int"
TThostFtdcServiceLineNoType = "int"
TThostFtdcServiceNameType = "string"
TThostFtdcLinkStatusType = "char"
TThostFtdcCommApiPointerType = "int"
TThostFtdcPwdFlagType = "char"
TThostFtdcSecuAccTypeType = "char"
TThostFtdcTransferStatusType = "char"
TThostFtdcSponsorTypeType = "char"
TThostFtdcReqRspTypeType = "char"
TThostFtdcFBTUserEventTypeType = "char"
TThostFtdcBankIDByBankType = "string"
TThostFtdcBankOperNoType = "string"
TThostFtdcBankCustNoType = "string"
TThostFtdcDBOPSeqNoType = "int"
TThostFtdcTableNameType = "string"
TThostFtdcPKNameType = "string"
TThostFtdcPKValueType = "string"
TThostFtdcDBOperationType = "char"
TThostFtdcSyncFlagType = "char"
TThostFtdcTargetIDType = "string"
TThostFtdcSyncTypeType = "char"
TThostFtdcFBETimeType = "string"
TThostFtdcFBEBankNoType = "string"
TThostFtdcFBECertNoType = "string"
TThostFtdcExDirectionType = "char"
TThostFtdcFBEBankAccountType = "string"
TThostFtdcFBEBankAccountNameType = "string"
TThostFtdcFBEAmtType = "double"
TThostFtdcFBEBusinessTypeType = "string"
TThostFtdcFBEPostScriptType = "string"
TThostFtdcFBERemarkType = "string"
TThostFtdcExRateType = "double"
TThostFtdcFBEResultFlagType = "char"
TThostFtdcFBERtnMsgType = "string"
TThostFtdcFBEExtendMsgType = "string"
TThostFtdcFBEBusinessSerialType = "string"
TThostFtdcFBESystemSerialType = "string"
TThostFtdcFBETotalExCntType = "int"
TThostFtdcFBEExchStatusType = "char"
TThostFtdcFBEFileFlagType = "char"
TThostFtdcFBEAlreadyTradeType = "char"
TThostFtdcFBEOpenBankType = "string"
TThostFtdcFBEUserEventTypeType = "char"
TThostFtdcFBEFileNameType = "string"
TThostFtdcFBEBatchSerialType = "string"
TThostFtdcFBEReqFlagType = "char"
TThostFtdcNotifyClassType = "char"
TThostFtdcRiskNofityInfoType = "string"
TThostFtdcForceCloseSceneIdType = "string"
TThostFtdcForceCloseTypeType = "char"
TThostFtdcInstrumentIDsType = "string"
TThostFtdcRiskNotifyMethodType = "char"
TThostFtdcRiskNotifyStatusType = "char"
TThostFtdcRiskUserEventType = "char"
TThostFtdcParamIDType = "int"
TThostFtdcParamNameType = "string"
TThostFtdcParamValueType = "string"
TThostFtdcConditionalOrderSortTypeType = "char"
TThostFtdcSendTypeType = "char"
TThostFtdcClientIDStatusType = "char"
TThostFtdcIndustryIDType = "string"
TThostFtdcQuestionIDType = "string"
TThostFtdcQuestionContentType = "string"
TThostFtdcOptionIDType = "string"
TThostFtdcOptionContentType = "string"
TThostFtdcQuestionTypeType = "char"
TThostFtdcProcessIDType = "string"
TThostFtdcSeqNoType = "int"
TThostFtdcUOAProcessStatusType = "string"
TThostFtdcProcessTypeType = "string"
TThostFtdcBusinessTypeType = "char"
TThostFtdcCfmmcReturnCodeType = "char"
TThostFtdcExReturnCodeType = "int"
TThostFtdcClientTypeType = "char"
TThostFtdcExchangeIDTypeType = "char"
TThostFtdcExClientIDTypeType = "char"
TThostFtdcClientClassifyType = "string"
TThostFtdcUOAOrganTypeType = "string"
TThostFtdcUOACountryCodeType = "string"
TThostFtdcAreaCodeType = "string"
TThostFtdcFuturesIDType = "string"
TThostFtdcCffmcDateType = "string"
TThostFtdcCffmcTimeType = "string"
TThostFtdcNocIDType = "string"
TThostFtdcUpdateFlagType = "char"
TThostFtdcApplyOperateIDType = "char"
TThostFtdcApplyStatusIDType = "char"
TThostFtdcSendMethodType = "char"
TThostFtdcEventTypeType = "string"
TThostFtdcEventModeType = "char"
TThostFtdcUOAAutoSendType = "char"
TThostFtdcQueryDepthType = "int"
TThostFtdcDataCenterIDType = "int"
TThostFtdcFlowIDType = "char"
TThostFtdcCheckLevelType = "char"
TThostFtdcCheckNoType = "int"
TThostFtdcCheckStatusType = "char"
TThostFtdcUsedStatusType = "char"
TThostFtdcRateTemplateNameType = "string"
TThostFtdcPropertyStringType = "string"
TThostFtdcBankAcountOriginType = "char"
TThostFtdcMonthBillTradeSumType = "char"
TThostFtdcFBTTradeCodeEnumType = "char"
TThostFtdcRateTemplateIDType = "string"
TThostFtdcRiskRateType = "string"
TThostFtdcTimestampType = "int"
TThostFtdcInvestorIDRuleNameType = "string"
TThostFtdcInvestorIDRuleExprType = "string"
TThostFtdcLastDriftType = "int"
TThostFtdcLastSuccessType = "int"
TThostFtdcAuthKeyType = "string"
TThostFtdcSerialNumberType = "string"
TThostFtdcOTPTypeType = "char"
TThostFtdcOTPVendorsIDType = "string"
TThostFtdcOTPVendorsNameType = "string"
TThostFtdcOTPStatusType = "char"
TThostFtdcBrokerUserTypeType = "char"
TThostFtdcFutureTypeType = "char"
TThostFtdcFundEventTypeType = "char"
TThostFtdcAccountSourceTypeType = "char"
TThostFtdcCodeSourceTypeType = "char"
TThostFtdcUserRangeType = "char"
TThostFtdcTimeSpanType = "string"
TThostFtdcImportSequenceIDType = "string"
TThostFtdcByGroupType = "char"
TThostFtdcTradeSumStatModeType = "char"
TThostFtdcComTypeType = "int"
TThostFtdcUserProductIDType = "string"
TThostFtdcUserProductNameType = "string"
TThostFtdcUserProductMemoType = "string"
TThostFtdcCSRCCancelFlagType = "string"
TThostFtdcCSRCDateType = "string"
TThostFtdcCSRCInvestorNameType = "string"
TThostFtdcCSRCOpenInvestorNameType = "string"
TThostFtdcCSRCInvestorIDType = "string"
TThostFtdcCSRCIdentifiedCardNoType = "string"
TThostFtdcCSRCClientIDType = "string"
TThostFtdcCSRCBankFlagType = "string"
TThostFtdcCSRCBankAccountType = "string"
TThostFtdcCSRCOpenNameType = "string"
TThostFtdcCSRCMemoType = "string"
TThostFtdcCSRCTimeType = "string"
TThostFtdcCSRCTradeIDType = "string"
TThostFtdcCSRCExchangeInstIDType = "string"
TThostFtdcCSRCMortgageNameType = "string"
TThostFtdcCSRCReasonType = "string"
TThostFtdcIsSettlementType = "string"
TThostFtdcCSRCMoneyType = "double"
TThostFtdcCSRCPriceType = "double"
TThostFtdcCSRCOptionsTypeType = "string"
TThostFtdcCSRCStrikePriceType = "double"
TThostFtdcCSRCTargetProductIDType = "string"
TThostFtdcCSRCTargetInstrIDType = "string"
TThostFtdcCommModelNameType = "string"
TThostFtdcCommModelMemoType = "string"
TThostFtdcExprSetModeType = "char"
TThostFtdcRateInvestorRangeType = "char"
TThostFtdcAgentBrokerIDType = "string"
TThostFtdcDRIdentityIDType = "int"
TThostFtdcDRIdentityNameType = "string"
TThostFtdcDBLinkIDType = "string"
TThostFtdcSyncDataStatusType = "char"
TThostFtdcTradeSourceType = "char"
TThostFtdcFlexStatModeType = "char"
TThostFtdcByInvestorRangeType = "char"
TThostFtdcSRiskRateType = "string"
TThostFtdcSequenceNo12Type = "int"
TThostFtdcPropertyInvestorRangeType = "char"
TThostFtdcFileStatusType = "char"
TThostFtdcFileGenStyleType = "char"
TThostFtdcSysOperModeType = "char"
TThostFtdcSysOperTypeType = "char"
TThostFtdcCSRCDataQueyTypeType = "char"
TThostFtdcFreezeStatusType = "char"
TThostFtdcStandardStatusType = "char"
TThostFtdcCSRCFreezeStatusType = "string"
TThostFtdcRightParamTypeType = "char"
TThostFtdcRightTemplateIDType = "string"
TThostFtdcRightTemplateNameType = "string"
TThostFtdcDataStatusType = "char"
TThostFtdcAMLCheckStatusType = "char"
TThostFtdcAmlDateTypeType = "char"
TThostFtdcAmlCheckLevelType = "char"
TThostFtdcAmlCheckFlowType = "string"
TThostFtdcDataTypeType = "string"
TThostFtdcExportFileTypeType = "char"
TThostFtdcSettleManagerTypeType = "char"
TThostFtdcSettleManagerIDType = "string"
TThostFtdcSettleManagerNameType = "string"
TThostFtdcSettleManagerLevelType = "char"
TThostFtdcSettleManagerGroupType = "char"
TThostFtdcCheckResultMemoType = "string"
TThostFtdcFunctionUrlType = "string"
TThostFtdcAuthInfoType = "string"
TThostFtdcAuthCodeType = "string"
TThostFtdcLimitUseTypeType = "char"
TThostFtdcDataResourceType = "char"
TThostFtdcMarginTypeType = "char"
TThostFtdcActiveTypeType = "char"
TThostFtdcMarginRateTypeType = "char"
TThostFtdcBackUpStatusType = "char"
TThostFtdcInitSettlementType = "char"
TThostFtdcReportStatusType = "char"
TThostFtdcSaveStatusType = "char"
TThostFtdcSettArchiveStatusType = "char"
TThostFtdcCTPTypeType = "char"
TThostFtdcToolIDType = "string"
TThostFtdcToolNameType = "string"
TThostFtdcCloseDealTypeType = "char"
TThostFtdcMortgageFundUseRangeType = "char"
TThostFtdcCurrencyUnitType = "double"
TThostFtdcExchangeRateType = "double"
TThostFtdcSpecProductTypeType = "char"
TThostFtdcFundMortgageTypeType = "char"
TThostFtdcAccountSettlementParamIDType = "char"
TThostFtdcCurrencyNameType = "string"
TThostFtdcCurrencySignType = "string"
TThostFtdcFundMortDirectionType = "char"
TThostFtdcBusinessClassType = "char"
TThostFtdcSwapSourceTypeType = "char"
TThostFtdcCurrExDirectionType = "char"
TThostFtdcCurrencySwapStatusType = "char"
TThostFtdcCurrExchCertNoType = "string"
TThostFtdcBatchSerialNoType = "string"
TThostFtdcReqFlagType = "char"
TThostFtdcResFlagType = "char"
TThostFtdcPageControlType = "string"
TThostFtdcRecordCountType = "int"
TThostFtdcCurrencySwapMemoType = "string"
TThostFtdcExStatusType = "char"
TThostFtdcClientRegionType = "char"
TThostFtdcWorkPlaceType = "string"
TThostFtdcBusinessPeriodType = "string"
TThostFtdcWebSiteType = "string"
TThostFtdcUOAIdCardTypeType = "string"
TThostFtdcClientModeType = "string"
TThostFtdcInvestorFullNameType = "string"
TThostFtdcUOABrokerIDType = "string"
TThostFtdcUOAZipCodeType = "string"
TThostFtdcUOAEMailType = "string"
TThostFtdcOldCityType = "string"
TThostFtdcCorporateIdentifiedCardNoType = "string"
TThostFtdcHasBoardType = "char"
TThostFtdcStartModeType = "char"
TThostFtdcTemplateTypeType = "char"
TThostFtdcLoginModeType = "char"
TThostFtdcPromptTypeType = "char"
TThostFtdcLedgerManageIDType = "string"
TThostFtdcInvestVarietyType = "string"
TThostFtdcBankAccountTypeType = "string"
TThostFtdcLedgerManageBankType = "string"
TThostFtdcCffexDepartmentNameType = "string"
TThostFtdcCffexDepartmentCodeType = "string"
TThostFtdcHasTrusteeType = "char"
TThostFtdcCSRCMemo1Type = "string"
TThostFtdcAssetmgrCFullNameType = "string"
TThostFtdcAssetmgrApprovalNOType = "string"
TThostFtdcAssetmgrMgrNameType = "string"
TThostFtdcAmTypeType = "char"
TThostFtdcCSRCAmTypeType = "string"
TThostFtdcCSRCFundIOTypeType = "char"
TThostFtdcCusAccountTypeType = "char"
TThostFtdcCSRCNationalType = "string"
TThostFtdcCSRCSecAgentIDType = "string"
TThostFtdcLanguageTypeType = "char"
TThostFtdcAmAccountType = "string"
TThostFtdcAssetmgrClientTypeType = "char"
TThostFtdcAssetmgrTypeType = "char"
TThostFtdcUOMType = "string"
TThostFtdcSHFEInstLifePhaseType = "string"
TThostFtdcSHFEProductClassType = "string"
TThostFtdcPriceDecimalType = "string"
TThostFtdcInTheMoneyFlagType = "string"
TThostFtdcCheckInstrTypeType = "char"
TThostFtdcDeliveryTypeType = "char"
TThostFtdcBigMoneyType = "double"
TThostFtdcMaxMarginSideAlgorithmType = "char"
TThostFtdcDAClientTypeType = "char"
TThostFtdcCombinInstrIDType = "string"
TThostFtdcCombinSettlePriceType = "string"
TThostFtdcDCEPriorityType = "int"
TThostFtdcTradeGroupIDType = "int"
TThostFtdcIsCheckPrepaType = "int"
TThostFtdcUOAAssetmgrTypeType = "char"
TThostFtdcDirectionEnType = "char"
TThostFtdcOffsetFlagEnType = "char"
TThostFtdcHedgeFlagEnType = "char"
TThostFtdcFundIOTypeEnType = "char"
TThostFtdcFundTypeEnType = "char"
TThostFtdcFundDirectionEnType = "char"
TThostFtdcFundMortDirectionEnType = "char"
TThostFtdcSwapBusinessTypeType = "string"
TThostFtdcOptionsTypeType = "char"
TThostFtdcStrikeModeType = "char"
TThostFtdcStrikeTypeType = "char"
TThostFtdcApplyTypeType = "char"
TThostFtdcGiveUpDataSourceType = "char"
TThostFtdcExecOrderSysIDType = "string"
TThostFtdcExecResultType = "char"
TThostFtdcStrikeSequenceType = "int"
TThostFtdcStrikeTimeType = "string"
TThostFtdcCombinationTypeType = "char"
TThostFtdcOptionRoyaltyPriceTypeType = "char"
TThostFtdcBalanceAlgorithmType = "char"
TThostFtdcActionTypeType = "char"
TThostFtdcForQuoteStatusType = "char"
TThostFtdcValueMethodType = "char"
TThostFtdcExecOrderPositionFlagType = "char"
TThostFtdcExecOrderCloseFlagType = "char"
TThostFtdcProductTypeType = "char"
TThostFtdcCZCEUploadFileNameType = "char"
TThostFtdcDCEUploadFileNameType = "char"
TThostFtdcSHFEUploadFileNameType = "char"
TThostFtdcCFFEXUploadFileNameType = "char"
TThostFtdcCombDirectionType = "char"
TThostFtdcLockTypeType = "char"
TThostFtdcBizTypeType = "char"
TThostFtdcDesignateTypeType = "char"
TThostFtdcFreezeReasonTypeType = "char"
TThostFtdcFreezeTypeType = "char"
TThostFtdcTradeSystemTypeType = "char"
TThostFtdcStockDisposalTypeType = "char"
TThostFtdcStockDisposalSysIDType = "string"
TThostFtdcStockDisposalStatusType = "char"
TThostFtdcInstructionRightTypeType = "char"
TThostFtdcLevelTypeType = "char"
TThostFtdcStrikeOffsetTypeType = "char"
TThostFtdcLoginRemarkType = "string"
TThostFtdcInvestUnitIDType = "string"
TThostFtdcBulletinIDType = "int"
TThostFtdcNewsTypeType = "string"
TThostFtdcNewsUrgencyType = "char"
TThostFtdcAbstractType = "string"
TThostFtdcComeFromType = "string"
TThostFtdcURLLinkType = "string"
TThostFtdcSmsCodeType = "string"
TThostFtdcSmsCodeStatusType = "char"
TThostFtdcEncryptPasswordType = "string"
TThostFtdcRandomStringType = "string"
TThostFtdcPasswordEncryptTypeType = "int"
TThostFtdcDateTimeType = "string"
TThostFtdcWeakPasswordSourceType = "char"
TThostFtdcOptSelfCloseFlagType = "char"
TThostFtdcAppTypeType = "char"
TThostFtdcAppIDType = "string"
TThostFtdcSystemInfoLenType = "int"
TThostFtdcAdditionalInfoLenType = "int"
TThostFtdcClientSystemInfoType = "string"
TThostFtdcAdditionalInfoType = "string"
TThostFtdcBase64ClientSystemInfoType = "string"
TThostFtdcBase64AdditionalInfoType = "string"
TThostFtdcCurrentAuthMethodType = "int"
TThostFtdcCaptchaInfoLenType = "int"
TThostFtdcCaptchaInfoType = "string"
TThostFtdcUserTextSeqType = "int"
TThostFtdcHandshakeDataType = "string"
TThostFtdcHandshakeDataLenType = "int"
TThostFtdcCryptoKeyVersionType = "string"
TThostFtdcRsaKeyVersionType = "int"
TThostFtdcSoftwareProviderIDType = "string"
TThostFtdcCollectTimeType = "string"
TThostFtdcQueryFreqType = "int"
TThostFtdcOwnerTypeType = "string"
TThostFtdcReserveOpenAccStasType = "char"
TThostFtdcSFInterestTypeType = "char"
TThostFtdcInterestSuccessType = "char"
TThostFtdcSFBankIDType = "string"
TThostFtdcSFBrokerIDType = "string"
TThostFtdcSFSecOrgIDType = "string"
TThostFtdcSFTradeTimeType = "string"
TThostFtdcSFBankSerialType = "string"
TThostFtdcSFSECSerialType = "string"
TThostFtdcSFBankAccountType = "string"
TThostFtdcSFInvestorNameType = "string"
TThostFtdcSFSponsorTypeType = "char"
TThostFtdcSFFBTransferDirectionType = "char"
TThostFtdcSFCashRemitFlagType = "char"
TThostFtdcSFMoneyType = "string"
TThostFtdcSFStatusType = "char"
TThostFtdcSFTradeTypeType = "string"
TThostFtdcSFBuySellFlagType = "char"
TThostFtdcSFTradeSettleAccountIDType = "string"
TThostFtdcSFAgreeNumberType = "string"
TThostFtdcSFIdCardTypeType = "char"
TThostFtdcSFIdentifiedCardNoType = "string"
TThostFtdcSFMarketIDType = "char"
TThostFtdcSFBankNameType = "string"
TThostFtdcInternalFundDirectionType = "char"
TThostFtdcSyncDepositStatusType = "char"
TThostFtdcFundServerStatusType = "char"
TThostFtdcFundServerRedoFlagType = "char"
TThostFtdcInternalTransferStatusType = "char"
TThostFtdcInstrumentNameType = "string"
TThostFtdcPbuSequenceIDType = "string"
TThostFtdcSendingTimeType = "string"
TThostFtdcLinearMarginTypeType = "char"
TThostFtdcETFOptionCombTypeType = "string"
TThostFtdcSFBrokerBranchType = "string"
TThostFtdcHSInvestorNameType = "string"
TThostFtdcSFFunctionCodeType = "string"
TThostFtdcLongAccountIDType = "string"
TThostFtdcBigVolumeType = "int"
